@@ -23,9 +23,9 @@
 
 #include "artikulatecore_export.h"
 #include "core/icourse.h"
-#include <memory>
 #include <QObject>
 #include <QVector>
+#include <memory>
 
 class QString;
 class CourseResourcePrivate;
@@ -85,9 +85,11 @@ public:
      */
     std::shared_ptr<ILanguage> language() const override;
 
+    QString languageTitle() const override;
+
     void setLanguage(std::shared_ptr<ILanguage> language);
 
-    std::shared_ptr<Unit> addUnit(std::unique_ptr<Unit> unit);
+    std::shared_ptr<Unit> addUnit(std::shared_ptr<Unit> unit);
 
     void sync();
 
