@@ -19,26 +19,25 @@
  */
 
 #include "mainwindow.h"
-#include "ui/resourcesdialogpage.h"
-#include "ui/sounddevicedialogpage.h"
-#include "ui/appearencedialogpage.h"
-#include "core/resourcerepository.h"
-#include "core/trainingsession.h"
-#include "core/editorsession.h"
-#include "core/resources/courseresource.h"
 #include "application.h"
+#include "artikulate_debug.h"
+#include "core/editorsession.h"
+#include "core/resourcerepository.h"
+#include "core/resources/courseresource.h"
+#include "core/trainingsession.h"
+#include "liblearnerprofile/src/learner.h"
+#include "liblearnerprofile/src/profilemanager.h"
+#include "libsound/src/outputdevicecontroller.h"
 #include "models/languagemodel.h"
 #include "settings.h"
-#include "liblearnerprofile/src/profilemanager.h"
-#include "liblearnerprofile/src/learner.h"
-#include "libsound/src/outputdevicecontroller.h"
-#include "artikulate_debug.h"
+#include "ui/sounddevicedialogpage.h"
 
+#include <KAboutData>
 #include <KActionCollection>
 #include <KConfigDialog>
 #include <KHelpMenu>
-#include <KLocalizedString>
 #include <KLocalizedContext>
+#include <KLocalizedString>
 #include <KNS3/DownloadDialog>
 #include <KStandardAction>
 
@@ -52,7 +51,6 @@ using namespace LearnerProfile;
 
 MainWindow::MainWindow()
     : m_actionCollection(new KActionCollection(this, QStringLiteral("artikulate")))
-    , m_helpMenu(new KHelpMenu)
     , m_profileManager(new LearnerProfile::ProfileManager(this))
     , m_trainingSession(new TrainingSession(m_profileManager, this))
 {
@@ -67,30 +65,22 @@ MainWindow::MainWindow()
     // set view
     rootContext()->setContextProperty(QStringLiteral("g_trainingSession"), m_trainingSession);
     rootContext()->setContextProperty(QStringLiteral("g_profileManager"), m_profileManager);
-    rootContext()->setContextProperty(QStringLiteral("kcfg_UseContributorResources"), Settings::useCourseRepository());
-    rootContext()->setContextProperty(QStringLiteral("kcfg_ShowMenuBar"), Settings::showMenuBar());
+    rootContext()->setContextProperty(QStringLiteral("g_artikulateAboutData"), QVariant::fromValue(KAboutData::applicationData()));
 
     // set starting screen
     load(QUrl(QStringLiteral("qrc:/artikulate/qml/Main.qml")));
 
-    // settings from kcfg values
-//     updateTrainingPhraseFont(); //FIXME deactivated while porting
-
     // create training profile if none exists:
     if (!m_profileManager->activeProfile()) {
         m_profileManager->addProfile(i18n("Unnamed Identity"));
     }
 
     // connect to QML signals;
-    connect(rootObjects().constFirst(), SIGNAL(ghnsCourseDataStatusChanged()),
-            this, SLOT(updateCourseResources()));
-    connect(rootObjects().constFirst(), SIGNAL(triggerAction(QString)),
-            this, SLOT(triggerAction(QString)));
-    connect(rootObjects().constFirst(), SIGNAL(switchMenuBarVisibility()),
-            this, SLOT(switchMenuBarVisibility()));
+    connect(rootObjects().constFirst(), SIGNAL(ghnsCourseDataStatusChanged()), this, SLOT(updateCourseResources()));
+    connect(rootObjects().constFirst(), SIGNAL(triggerAction(QString)), this, SLOT(triggerAction(QString)));
 
     // set font for the phrase in trainer to default from kcfg file
-    QObject *phraseText = rootObjects().constFirst()->findChild<QObject*>(QStringLiteral("phraseText"));
+    QObject *phraseText = rootObjects().constFirst()->findChild<QObject *>(QStringLiteral("phraseText"));
     if (phraseText) {
         phraseText->setProperty("font", Settings::trainingPhraseFont());
     }
@@ -103,7 +93,7 @@ MainWindow::~MainWindow()
     m_profileManager->sync();
 }
 
-KActionCollection * MainWindow::actionCollection()
+KActionCollection *MainWindow::actionCollection()
 {
     return m_actionCollection;
 }
@@ -120,11 +110,6 @@ void MainWindow::setupActions()
     actionCollection()->addAction(QStringLiteral("config_learner_profile"), configLearnerProfileAction);
     configLearnerProfileAction->setIcon(QIcon::fromTheme(QStringLiteral("user-identity")));
 
-    KStandardAction::helpContents(m_helpMenu, SLOT(appHelpActivated()), actionCollection());
-    KStandardAction::reportBug(m_helpMenu, SLOT(reportBug()), actionCollection());
-    KStandardAction::aboutKDE(m_helpMenu, SLOT(aboutKDE()), actionCollection());
-    KStandardAction::aboutApp(m_helpMenu, SLOT(aboutApplication()), actionCollection());
-
     KStandardAction::quit(qApp, SLOT(quit()), actionCollection());
 }
 
@@ -136,19 +121,12 @@ void MainWindow::showSettingsDialog()
     QPointer<KConfigDialog> dialog = new KConfigDialog(nullptr, QStringLiteral("settings"), Settings::self());
 
     SoundDeviceDialogPage *soundDialog = new SoundDeviceDialogPage();
-    AppearenceDialogPage *appearenceDialog = new AppearenceDialogPage();
 
-//    resourceDialog->loadSettings();
     soundDialog->loadSettings();
-    appearenceDialog->loadSettings();
 
     dialog->addPage(soundDialog, i18nc("@item:inmenu", "Sound Devices"), QStringLiteral("audio-headset"), i18nc("@title:tab", "Sound Device Settings"), true);
-    dialog->addPage(appearenceDialog, i18nc("@item:inmenu", "Fonts"), QStringLiteral("preferences-desktop-font"), i18nc("@title:tab", "Training Phrase Font"), true);
 
-//     connect(dialog, SIGNAL(settingsChanged(const QString&)), resourceDialog, SLOT(loadSettings()));
-//     connect(dialog, SIGNAL(settingsChanged(const QString&)), soundDialog, SLOT(loadSettings()));
     connect(dialog.data(), &QDialog::accepted, soundDialog, &SoundDeviceDialogPage::saveSettings);
-    connect(dialog.data(), &QDialog::accepted, appearenceDialog, &AppearenceDialogPage::saveSettings);
     connect(dialog.data(), &QDialog::accepted, this, &MainWindow::updateTrainingPhraseFont);
     connect(dialog.data(), &QDialog::accepted, this, &MainWindow::updateKcfgUseContributorResources);
     connect(dialog.data(), &QDialog::finished, soundDialog, &SoundDeviceDialogPage::stopPlaying);
@@ -164,7 +142,7 @@ void MainWindow::updateCourseResources()
 
 void MainWindow::updateTrainingPhraseFont()
 {
-    QObject *phraseText = rootObjects().constFirst()->findChild<QObject*>(QStringLiteral("phraseText"));
+    QObject *phraseText = rootObjects().constFirst()->findChild<QObject *>(QStringLiteral("phraseText"));
     if (!phraseText) {
         qCDebug(ARTIKULATE_LOG) << "no phraseText context object found, aborting";
         return;
@@ -179,12 +157,12 @@ void MainWindow::updateKcfgUseContributorResources()
 
 void MainWindow::configLearnerProfile()
 {
-    qCritical() << "Not implemented"; //FIXME
+    qCritical() << "Not implemented"; // FIXME
 }
 
 void MainWindow::triggerAction(const QString &actionName)
 {
-    QAction * action = actionCollection()->action(actionName);
+    QAction *action = actionCollection()->action(actionName);
     if (action) {
         action->trigger();
     } else {
